@@ -36,15 +36,16 @@ class Marketplace(BaseContract[MarketplaceABI]):
 
     ```python
     from thirdweb import ThirdwebSDK
-    from eth_account import Account
-    from web3 import Web3
 
-    # You can switch out this provider and RPC URL for your own
-    provider = Web3(Web3.HTTPProvider("<RPC_URL>"))
-    # This will create a random account to use for signing transactions
-    signer = Account.create()
+    # You can customize this to a supported network or your own RPC URL
+    network = "mumbai"
+
+    # Now we can create a new instance of the SDK
+    sdk = ThirdwebSDK(network)
+
+    # If you want to send transactions, you can instantiate the SDK with a private key instead:
+    #   sdk = ThirdwebSDK.from_private_key(PRIVATE_KEY, network)
 
-    sdk = ThirdwebSDK(provider, signer)
     contract = sdk.get_marketplace("{{contract_address}}")
     ```
     """
