@@ -3,12 +3,14 @@ from thirdweb.abi.token_erc1155 import ITokenERC1155MintRequest
 from thirdweb.common.currency import normalize_price_value, set_erc20_allowance
 from thirdweb.common.nft import upload_or_extract_uris
 from thirdweb.common.sign import EIP712StandardDomain
+from thirdweb.constants.chains import ChainId
 from thirdweb.constants.role import Role
 from thirdweb.core.classes.ipfs_storage import IpfsStorage
 from thirdweb.core.classes.contract_wrapper import ContractWrapper
 from thirdweb.core.classes.contract_roles import ContractRoles
 from thirdweb.abi import TokenERC1155
 from thirdweb.types.tx import TxResultWithId
+from zero_ex.contract_wrappers.tx_params import TxParams
 from thirdweb.types.contracts.signature import (
     EIP712DomainType,
     MintRequest1155,
@@ -47,7 +49,7 @@ class ERC1155SignatureMinting:
         message = self._map_payload_to_contract_struct(mint_request)
 
         # TODO: OVERRIDES
-        overrides: Dict[str, Any] = {}
+        overrides: TxParams = TxParams()
         set_erc20_allowance(
             self._contract_wrapper,
             message["pricePerToken"] * message["quantity"],
@@ -55,7 +57,7 @@ class ERC1155SignatureMinting:
             overrides,
         )
         receipt = self._contract_wrapper.send_transaction(
-            "mint_with_signature", [message, signature]
+            "mint_with_signature", [message, signature], overrides
         )
         events = self._contract_wrapper.get_events("TokensMintedWithSignature", receipt)
 
@@ -145,10 +147,9 @@ class ERC1155SignatureMinting:
         parsed_requests = payloads_to_sign
         metadatas = [request.metadata for request in parsed_requests]
         uris = upload_or_extract_uris(metadatas, self._storage)
-
         chain_id = self._contract_wrapper.get_chain_id()
-        signer = self._contract_wrapper.get_signer()
 
+        signer = self._contract_wrapper.get_signer()
         if signer is None:
             raise Exception("No signer found")
 
