@@ -16,6 +16,7 @@ from thirdweb.constants.urls import (
 )
 from thirdweb.core.helpers.storage import (
     replace_file_properties_with_hashes,
+    replace_gateway_url_with_hash,
     replace_hash_with_gateway_url,
     resolve_gateway_url,
 )
@@ -23,21 +24,38 @@ from thirdweb.types.storage import CidWithFileName, UriWithMetadata
 
 
 class IpfsStorage(ABC):
+    """
+    Upload and download files from IPFS.
+
+    ```python
+    from thirdweb import ThirdwebSDK
+
+    # You can customize this to a supported network or your own RPC URL
+    network = "mumbai"
+
+    sdk = ThirdwebSDK(network)
+
+    # Now all the IPFS functions will be available on the sdk.storage name space
+    sdk.storage.get("<IPFS_HASH>")
+    ```
+    """
+
     _gateway_url: str
 
     def __init__(self, gateway_url=DEFAULT_IPFS_GATEWAY):
         self._gateway_url = re.sub(r"\/$", "", gateway_url) + "/"
 
-    def get(self, hash: str) -> Dict[str, Any]:
+    def get(self, hash: str) -> Any:
         """
-        Gets IPFS data at a given hash and returns it as a dictionary.
+        Gets IPFS data at a given hash and returns the data.
 
         :param hash: hash of the data to get.
-        :returns: dictionary of the data.
+        :returns: dictionary of the data if JSON, otherwise raw data.
         """
 
         res = self._get(hash)
         data = res.json()
+
         return replace_hash_with_gateway_url(data, "ipfs://", self._gateway_url)
 
     def get_upload_token(self, contract_address: str) -> str:
@@ -155,7 +173,7 @@ class IpfsStorage(ABC):
         return UriWithMetadata(base_uri, metadata_uris)
 
     """
-    PROTECTED FUNCTIONS
+    INTERNAL FUNCTIONS
     """
 
     def _get(self, hash: str) -> Response:
@@ -168,13 +186,19 @@ class IpfsStorage(ABC):
         return res
 
     def _batch_upload_properties(self, metadatas: Sequence[Dict[str, Any]]):
+        sanitized_metadatas = [
+            replace_gateway_url_with_hash(metadatas, "ipfs://", self._gateway_url)
+            for metadatas in metadatas
+        ]
+
         file_lists = [
-            self._build_file_properties_map(metadata, []) for metadata in metadatas
+            self._build_file_properties_map(metadata, [])
+            for metadata in sanitized_metadatas
         ]
         files_to_upload = [file for file_list in file_lists for file in file_list]
 
         if len(files_to_upload) == 0:
-            return metadatas
+            return sanitized_metadatas
 
         cid_with_filename = self._upload_batch_with_cid(
             cast(List[Union[TextIO, BinaryIO, str, Dict[str, Any]]], files_to_upload)
